!function(){try{var o="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};o.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var e=(new o.Error).stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="4d7ae2c0-c4e5-4816-8323-978bc0666aaa",o._sentryDebugIdIdentifier="sentry-dbid-4d7ae2c0-c4e5-4816-8323-978bc0666aaa")}catch(o){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[2576],{2576(o,e,t){t.r(e),t.d(e,{Notification:()=>c.Eg,Warning:()=>l,createErrorNotification:()=>c.gi,createNotification:()=>c.UI,default:()=>g,showDashboardCreatedNotification:()=>d.jE,showInvalidDashboardSlugNotification:()=>d.$j,showJoiningSpaceNotification:()=>d.Fw,showNodesNotification:()=>d.AM,showRoomCreationNotification:()=>d.ZM,showRoomsInSpaceNotification:()=>d.mw,showRoomsNotification:()=>d.r0,showSpaceNotification:()=>d.X7,showUsersInRoomNotification:()=>d.R9,showUsersInSpaceNotification:()=>d.sb,toast:()=>s.A});var i=t(882),r=t(56327),a=t(61409),n=t(74848),s=t(51900),d=t(50433),c=t(12724);const l=o=>{let{title:e,children:t,...i}=o;return(0,n.jsxs)(r.Flex,{column:!0,gap:2,background:"warningBackground",backgroundOpacity:.7,round:!0,padding:[4],...i,children:[e&&(0,n.jsx)(r.H3,{children:e}),t]})},g=(0,i.default)(o=>{let{className:e,...t}=o;return(0,n.jsx)(r.Box,{className:e,children:(0,n.jsx)(a.N9,{...t,closeButton:!1})})}).withConfig({displayName:"notifications__Container",componentId:"sc-8t8ne-0"})([".Toastify__toast-container{position:fixed;width:unset;min-width:400px;max-width:500px;z-index:150;color:",";}.Toastify__toast{padding:0;padding-top:5px;background:",";border:1px solid ",";}.Toastify__toast--error{background:",";border:1px solid ",";}.Toastify__toast--warning{background:",";border:1px solid ",";}.Toastify__toast--success{background:",";border:1px solid ",";}.Toastify__toast-icon{display:none;}.Toastify__progress-bar{bottom:unset;top:0;}.Toastify__progress-bar--success{background-color:",";}.Toastify__progress-bar--error{background-color:",";}"],(0,r.getColor)(["neutral","limedSpruce"]),(0,r.getColor)("elementBackground"),(0,r.getColor)("text"),(0,r.getColor)(["red","lavender"]),(0,r.getColor)("error"),(0,r.getColor)("bright"),(0,r.getColor)("warning"),(0,r.getColor)(["green","frostee"]),(0,r.getColor)("success"),(0,r.getColor)("success"),(0,r.getColor)("error"))}}]);