!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var d=(new e.Error).stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="aedfda13-6164-4c9e-8e40-59eb0e40d23b",e._sentryDebugIdIdentifier="sentry-dbid-aedfda13-6164-4c9e-8e40-59eb0e40d23b")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[5302],{5302(e,d,n){n.r(d),n.d(d,{default:()=>f});var s=n(96540),o=n(7960),r=n(51262),a=n(74848);const l=(0,o.A)(()=>n.e(6141).then(n.bind(n,56141)),"Modal"),t=e=>{const{loaded:d,hasLimitations:n,maxNodes:o,preferredNodes:t,refreshPreferredNodes:f,nodesCount:u}=(0,r.A)();return!(!d||!n)&&(u>o&&!t.length)?(0,a.jsx)(s.Suspense,{fallback:"",children:(0,a.jsx)(l,{onSuccessfulSave:f,...e})}):null},f=e=>(0,a.jsx)(t,{...e})}}]);