!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b13a7c68-0afe-4da9-96b7-7a07fec08f80",e._sentryDebugIdIdentifier="sentry-dbid-b13a7c68-0afe-4da9-96b7-7a07fec08f80")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[7877],{55093(e,t,n){n.d(t,{A:()=>r,m:()=>l});var a=n(882),d=n(56327),o=n(74848);const i=(0,a.keyframes)(["from{opacity:0.4;}to{opacity:1;}"]),s=(0,a.default)(d.Icon).withConfig({displayName:"loader__StyledIcon",componentId:"sc-a76ek6-0"})(["width:",";height:",";animation:",";"],e=>e.width,e=>e.height,e=>{let{animate:t}=e;return t?(0,a.css)([""," 1.6s ease-in infinite"],i):""}),l=e=>{let{title:t="Loading",width:n="208px",height:a="177px",...d}=e;return(0,o.jsx)(s,{name:"netdata",color:"primary",title:t,"data-testid":"loading-logo",width:n,height:a,...d})},r=e=>{let{title:t,body:n,iconProps:a,animate:i=!0,testId:s="",...r}=e;return(0,o.jsxs)(d.Flex,{column:!0,height:"100vh",background:"mainBackground",width:"100%",justifyContent:"center",alignItems:"center","data-testid":`loader-container-${s}`,...r,children:[(0,o.jsx)(l,{...a,animate:i}),t&&(0,o.jsx)(d.H3,{color:"text",margin:[1,0,0],children:t}),n&&(0,o.jsx)(d.Text,{color:"text",margin:[4.5,0,0],children:n})]})}},37877(e,t,n){n.r(t),n.d(t,{default:()=>x});var a=n(96540),d=n(7960),o=n(43276),i=n(5981),s=n(56327),l=n(46587),r=n(49389),c=n(84418),h=n(55093),f=n(62718),u=n(55164),m=n(96396),b=n(74848);const w=(0,d.A)(()=>Promise.all([n.e(2919),n.e(9654),n.e(2025)]).then(n.bind(n,24211)),"AlertWebview"),g=(0,d.A)(()=>Promise.all([n.e(3403),n.e(2919),n.e(9015),n.e(6874),n.e(4947),n.e(4596),n.e(4663),n.e(9654),n.e(1388),n.e(3746),n.e(7296),n.e(2977),n.e(7152)]).then(n.bind(n,31481)),"DashboardWebview"),p=(0,d.A)(()=>Promise.all([n.e(3403),n.e(2919),n.e(9015),n.e(6874),n.e(4947),n.e(4596),n.e(4663),n.e(9654),n.e(1388),n.e(3746),n.e(7296),n.e(8707),n.e(2977),n.e(6682)]).then(n.bind(n,75439)),"PlaylistWebview");window.webviewNetdataToken=null;const x=(I=(0,u.Xc)(()=>{const{search:e}=window.location,{space_id:t,room_id:n,node_name:d,node_id:u}=o.A.parse(e),m=(0,l.uW)("isLoaded");return(0,r.A)(),(0,c.A)(),m?(0,b.jsx)(s.Flex,{overflow:"hidden",height:"100vh",width:"100vw",children:(0,b.jsx)(a.Suspense,{fallback:(0,b.jsx)(f.xh,{}),children:(0,b.jsxs)(i.BV,{children:[(0,b.jsx)(i.qh,{path:"alerts/:alertId",element:(0,b.jsx)(w,{spaceId:t,roomId:n,nodeName:d,nodeId:u})}),(0,b.jsx)(i.qh,{path:"dashboards/:dashboardId",element:(0,b.jsx)(g,{spaceId:t,roomId:n})}),(0,b.jsx)(i.qh,{path:"playlists/:playlistId",element:(0,b.jsx)(p,{spaceId:t,roomId:n})})]})})}):(0,b.jsx)(h.A,{})}),e=>{const{hash:t}=window.location,{token:n}=o.A.parse(t),d=(0,m.RZ)(),[i,s]=(0,a.useState)(()=>d?localStorage.getItem(m.fZ):null);return(0,a.useEffect)(()=>{if(n){if(d)return localStorage.setItem(m.fZ,n),void s(n);window.webviewNetdataToken=n,s(n)}},[d,n]),i?(0,b.jsx)(I,{...e}):(0,b.jsx)(h.A,{})});var I},84418(e,t,n){n.d(t,{A:()=>i});var a=n(96540),d=n(89942),o=n(24285);const i=()=>{const e=(0,o.xd)("timezone"),t=(0,o.fW)("timezone");(0,a.useEffect)(()=>{const{utc:n}=(0,d.PP)();e||n&&"default"!==n&&t(n),(0,d.Pg)(["utc","offset","timezoneName"])},[])}}}]);