!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var o=(new e.Error).stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="1b45f483-9336-4fad-ac6f-af6ba6b902e6",e._sentryDebugIdIdentifier="sentry-dbid-1b45f483-9336-4fad-ac6f-af6ba6b902e6")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[2010],{18423(e,o,t){t.d(o,{R:()=>n,T:()=>d});const n=e=>{const o=`; ${document.cookie}`.split(`; ${e}=`);if(2===o.length)return o.pop().split(";").shift()},d=function(e,o){let t=arguments.length>2&&void 0!==arguments[2]?arguments[2]:0;const n=new Date;n.setTime(n.getTime()+24*t*60*60*1e3),document.cookie=`${e}=${o}; expires=${n.toUTCString()}; path=/`}},2010(e,o,t){t.r(o),t.d(o,{default:()=>f});var n=t(96540),d=t(56327),r=t(92318),s=t(18423),i=t(46587),a=t(24609),u=t(60908),c=t(3319),l=t(74848);const b=()=>{const{sendLog:e,isReady:o}=(0,c.A)();return(0,n.useEffect)(()=>{if(!o)return;if(window.hbspt?.forms)return void window.hbspt.forms.create({region:"na1",portalId:"4567453",formId:"d3749ae3-d192-40b4-9be6-3666bfabbbd0",target:"#hubspotForm"});const t=document.createElement("script");t.src="https://js.hsforms.net/forms/v2.js",document.body.appendChild(t),t.addEventListener("load",()=>{window.hbspt&&window.hbspt.forms.create({region:"na1",portalId:"4567453",formId:"d3749ae3-d192-40b4-9be6-3666bfabbbd0",target:"#hubspotForm",onFormSubmitted:(o,t)=>{(0,s.T)("demoContactFormSubmitted","true",365),e({feature:"DemoContact",message:"Demo form submitted",...t?.submissionValues||{}}),window.location.reload()}})})},[o]),o?(0,l.jsx)(d.Layer,{backdrop:!0,backdropProps:{backdropBlur:"3px"},children:(0,l.jsxs)(d.Flex,{column:!0,gap:4,background:"modalBackground",padding:[3,4,0],round:!0,width:100,children:[(0,l.jsx)(d.H2,{children:"Access Netdata\u2019s Live Demo"}),(0,l.jsx)(d.Flex,{id:"hubspotForm"})]})}):null},f=(0,n.memo)(()=>{const{demoSlug:e}=r.A,o=(0,a.bq)(),{isLoaded:t,isAnonymous:n}=(0,i.uW)();if(!t||!n)return null;if(e!==o)return null;if("production"!==window.envSettings.nodeEnv)return null;return"true"===(0,s.R)("demoContactFormSubmitted")?null:(0,l.jsx)(u.Ay,{feature:"DemoContact",children:(0,l.jsx)(b,{})})})}}]);