!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="4c86d055-4747-4184-9575-f3722377ca45",e._sentryDebugIdIdentifier="sentry-dbid-4c86d055-4747-4184-9575-f3722377ca45")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[7799],{80590(e,t,a){a.d(t,{A:()=>d});var n=a(96540),i=a(3319),o=a(74848);const d=e=>t=>{let{callback:a,feature:d,isStart:l,isSuccess:r,isFailure:c,eventReason:s,payload:u={},...h}=t;const{sendLog:g,isReady:f}=(0,i.A)(),p=(0,n.useCallback)(e=>{const t=h[a],n={...d?{feature:d}:{},...void 0!==l?{isStart:l}:{},...void 0!==r?{isSuccess:r}:{},...void 0!==c?{isFailure:c}:{},...s?{eventReason:s}:{},...u,...h["data-ga"]?{dataGa:h["data-ga"]}:{},...h.dataGa?{dataGa:h.dataGa}:{},...h["data-track"]?{dataTrack:h["data-track"]}:{},...h.label?{label:h.label}:{}};"function"===typeof t&&t(e),g(n,!0)},[a,g,f,u,h]),b=(0,n.useMemo)(()=>({...h,[a]:p}),[h,a,p]);return(0,o.jsx)(e,{...b})}},94404(e,t,a){a.d(t,{A:()=>d});var n=a(80590),i=a(81691),o=a(74848);const d=e=>t=>{let{payload:a={},...d}=t;const l=(0,n.A)(e);return(0,o.jsx)(l,{...d,callback:"onClick",payload:{...a,action:i.o1.buttonClicked}})}},55093(e,t,a){a.d(t,{A:()=>c,m:()=>r});var n=a(882),i=a(56327),o=a(74848);const d=(0,n.keyframes)(["from{opacity:0.4;}to{opacity:1;}"]),l=(0,n.default)(i.Icon).withConfig({displayName:"loader__StyledIcon",componentId:"sc-a76ek6-0"})(["width:",";height:",";animation:",";"],e=>e.width,e=>e.height,e=>{let{animate:t}=e;return t?(0,n.css)([""," 1.6s ease-in infinite"],d):""}),r=e=>{let{title:t="Loading",width:a="208px",height:n="177px",...i}=e;return(0,o.jsx)(l,{name:"netdata",color:"primary",title:t,"data-testid":"loading-logo",width:a,height:n,...i})},c=e=>{let{title:t,body:a,iconProps:n,animate:d=!0,testId:l="",...c}=e;return(0,o.jsxs)(i.Flex,{column:!0,height:"100vh",background:"mainBackground",width:"100%",justifyContent:"center",alignItems:"center","data-testid":`loader-container-${l}`,...c,children:[(0,o.jsx)(r,{...n,animate:d}),t&&(0,o.jsx)(i.H3,{color:"text",margin:[1,0,0],children:t}),a&&(0,o.jsx)(i.Text,{color:"text",margin:[4.5,0,0],children:a})]})}},67799(e,t,a){a.r(t),a.d(t,{MobileApp:()=>c,default:()=>s});var n=a(56327),i=a(55093),o=a(60908),d=a(94404),l=a(74848);const r=(0,d.A)(n.Button),c=()=>(0,l.jsx)(o.Ay,{feature:"MobileApp",children:(0,l.jsx)(n.Layer,{full:!0,children:(0,l.jsxs)(n.Flex,{alignItems:"center",justifyContent:"center",column:!0,width:"100%",height:"100%",background:"mainBackground",gap:4,children:[(0,l.jsx)(i.m,{}),(0,l.jsx)(n.TextBigger,{textAlign:"center",children:"Please open this link using your mobile device."}),(0,l.jsx)(n.Flex,{alignItems:"center",children:(0,l.jsx)(r,{onClick:()=>window.location.replace("/"),feature:"MobileApp",payload:{label:"Go to app"},children:"Go to app"})})]})})}),s=c}}]);