!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var d=(new e.Error).stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="23ad877c-b2cd-4d34-b06b-917e93a696d4",e._sentryDebugIdIdentifier="sentry-dbid-23ad877c-b2cd-4d34-b06b-917e93a696d4")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[3808],{43808(e,d,n){n.r(d),n.d(d,{default:()=>b});var t=n(5981),o=n(44245),i=n(74090),r=n(75250),s=n(99094),a=n(74848);const b=()=>{const{reportId:e}=(0,t.g)(),d=(0,r.A)({id:e});return(0,o.ZB)({title:d,id:e,destination:e,type:s.p9}),(0,a.jsx)(i.A,{})}}}]);