!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="332f725e-99db-4c9b-afc5-2d2209b46384",e._sentryDebugIdIdentifier="sentry-dbid-332f725e-99db-4c9b-afc5-2d2209b46384")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[7543],{77543(e,n,d){d.r(n),d.d(n,{default:()=>s});var t=d(96540),l=d(56327),r=d(23947),u=d(3319),f=d(62718),o=d(74848);const s=()=>{const{sendLog:e}=(0,u.A)(),n=(0,r.So)(),d=(0,t.useRef)(!1),s=(0,t.useCallback)(()=>{d.current||(d.current=!0,e({feature:"SignUpThankYou"}).finally(()=>{n()}))},[n]);return(0,t.useEffect)(()=>{let e=!0,n=setTimeout(()=>{e&&s()},1e3);return()=>{e=!1,n&&(clearTimeout(n),n=null)}},[]),(0,o.jsx)(l.Flex,{width:"100",height:"100vh",children:(0,o.jsx)(f.yj,{})})}}}]);