!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var t=(new e.Error).stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="22778be9-38a1-4907-9e79-6d32ed2491d9",e._sentryDebugIdIdentifier="sentry-dbid-22778be9-38a1-4907-9e79-6d32ed2491d9")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[2558],{12558(e,t,n){n.r(t),n.d(t,{default:()=>c});var o=n(96540),r=n(56327),d=n(56171),a=n(79748),s=n(6304),i=n(32886),l=n(74848);const c=()=>{const e=(0,i.e)(),[t,,n,c]=(0,s.A)();return(0,o.useEffect)(()=>{"Reachable"===e&&n()},[e]),t?(0,l.jsx)(r.Layer,{full:"horizontal",backdropProps:{backdropBlur:"3px"},onClickOutside:c,onEsc:c,position:"top",children:(0,l.jsxs)(d.A,{testId:"agent-not-secure-banner",width:"100%",background:"warningBackground",position:"absolute",top:"0",tooltipProps:{align:"top"},zIndex:20,children:[(0,l.jsx)(r.Flex,{justifyContent:"center",alignItems:"center",width:"100%",gap:2,children:(0,l.jsxs)(r.Text,{children:["IMPORTANT: This Netdata is openly accessible from the Internet!"," ",(0,l.jsx)(a.A,{"data-testid":"learn",href:"https://learn.netdata.cloud/docs/netdata-agent/securing-netdata-agents/",as:"a",cursor:"pointer",textDecoration:"underline",color:"text",hoverColor:"textFocus",children:"Secure your Netdata now"}),"!"]})}),(0,l.jsx)(r.Box,{"data-testid":"agent-not-secure-banner-close-button",as:r.Icon,color:"text",cursor:"pointer",name:"x",position:"absolute",right:"8px",onClick:c})]})}):null}}}]);