!function(){try{var n="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};n.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var e=(new n.Error).stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="82ef9439-6f6a-4f2d-93f0-92765464dd43",n._sentryDebugIdIdentifier="sentry-dbid-82ef9439-6f6a-4f2d-93f0-92765464dd43")}catch(n){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[7931],{43581(n,e,s){s.d(e,{A:()=>d});var t=s(22794),r=s(34412),a=s(74848);const d=n=>{let{children:e}=n;return(0,a.jsx)(t.A,{config:{nodes:r.A},children:e})}},27931(n,e,s){s.r(e),s.d(e,{default:()=>w});s(98992),s(81454);var t=s(56327),r=s(56171),a=s(53949),d=s(43581),i=s(17662),o=s(96540),c=s(24609),l=s(40545);const g=n=>{let{key:e}=n;const{id:s}=(0,l.A)(),t=(0,c.vt)();return(0,o.useCallback)(()=>`${e}-${s}-${t}`,[e,s,t])};var f=s(74848);const u=n=>{let{warningKey:e,warningLevel:s,text:o}=n;const{background:c,isDismissable:l,icon:u,iconColor:b}=i.f1[s],w=g({key:e}),{dismissed:y,onClose:h}=(0,a.A)({getLocalStorageKey:w,logKey:`${e}-dissmiss`});return y?null:(0,f.jsx)(r.A,{className:"space-warning-banner-container",testId:`space-warning-banner-${e}-${s}`,background:c,onClose:l?h:null,children:(0,f.jsxs)(t.Flex,{"data-testid":`text-space-warnings-${e}-${s}`,justifyContent:"center",alignItems:"center",width:"100%",gap:2,children:[(0,f.jsx)(t.Icon,{"data-testid":`icon-banner-space-warnings-${e}-${s}`,color:b,name:u}),(0,f.jsx)(d.A,{children:o})]})})};var b=s(68534);const w=()=>{const{warnings:n}=(0,b.A)();return(0,f.jsx)(f.Fragment,{children:n.map(n=>(0,f.jsx)(u,{...n},n.warningKey))})}},68534(n,e,s){s.d(e,{A:()=>r});s(98992),s(81454);var t=s(24609);const r=()=>{const n=(0,t.ap)(),{warnings:e}=n||{};return{warnings:(e||[]).map(n=>{let{kind:e,text:s,urgency:t}=n;return{warningKey:e,warningLevel:t||"info",text:s}})}}}}]);