!function(){try{var e="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};e.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var n=(new e.Error).stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b11c2379-9914-4372-8592-4a72c1b94064",e._sentryDebugIdIdentifier="sentry-dbid-b11c2379-9914-4372-8592-4a72c1b94064")}catch(e){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[891],{40891(e,n,d){d.r(n),d.d(n,{default:()=>l});var o=d(98591),s=d(42660),t=d(74031),a=d(74848);const l=()=>{const[e,,,n]=(0,o.A)("manageInvitations");return(0,a.jsx)(s.A,{children:e&&(0,a.jsx)(t.d,{onClose:n})})}}}]);