!function(){try{var d="undefined"!=typeof window?window:"undefined"!=typeof global?global:"undefined"!=typeof globalThis?globalThis:"undefined"!=typeof self?self:{};d.SENTRY_RELEASE={id:"6f8fd777495ec30113c7d19e3c90e6767827ed67"};var e=(new d.Error).stack;e&&(d._sentryDebugIds=d._sentryDebugIds||{},d._sentryDebugIds[e]="d1b6a1bb-1dff-4140-a36e-b865953a1910",d._sentryDebugIdIdentifier="sentry-dbid-d1b6a1bb-1dff-4140-a36e-b865953a1910")}catch(d){}}(),(globalThis.webpackChunkcloud_frontend=globalThis.webpackChunkcloud_frontend||[]).push([[5297],{95297(d,e,o){o.r(e),o.d(e,{DashboardContent:()=>A,default:()=>m});o(33110);var a=o(96540),t=o(5981),s=o(96243);const n=d=>{const{dashboardSlug:e=d}=(0,t.g)(),o=(0,s.Xv)(),n=(0,s.Tf)();return(0,a.useEffect)(()=>{n!==e&&o(e)},[n,e]),(0,a.useEffect)(()=>()=>o(null),[]),e};o.dn(n);var r=o(93933),i=o(24609),l=o(19186),b=o(41579),u=o(67294),f=o(96957),c=o(44245),h=o(88314),g=o(1623),p=o(41388),y=o(12407),I=o(60908),v=o(74848);const A=d=>{let{id:e}=d;const o=(0,i.vt)(),a=(0,i.bq)(),t=(0,l.ID)(),s=(0,l.QW)(),n=(0,f.oj)("state"),r=(0,h.A)(e,{spaceId:o,spaceSlug:a,roomId:t,roomSlug:s});return r?(0,v.jsx)(g.A,{}):(0,v.jsx)(I.Ay,{feature:"Dashboard",dashboardId:e,children:"notAvailable"===n?(0,v.jsx)(y.A,{flavour:"dashboard"}):(0,v.jsx)(p.A,{id:e},JSON.stringify({id:e,loading:r}))})},m=(0,a.memo)(d=>{let{customDashboardId:e}=d;(0,b.A)(),n(e),(0,r.z1)(e);const o=(0,f.zi)(e),a=(0,f.oj)("slug");(0,c.ZB)({title:a,id:o,destination:a,type:"dashboards",droppable:!0,droppableProps:{dashboardId:o,dropArea:!0},tooltip:{title:a,description:"Custom dashboard with personalized visualizations and metrics tailored to your monitoring requirements."}});const t=(0,u.RQ)();return(0,v.jsx)(A,{id:t?o:null})})},1623(d,e,o){o.d(e,{A:()=>s});var a=o(63474),t=o(74848);const s=()=>(0,t.jsx)(a.O2,{"data-testid":"dashboardLoading"})}}]);